controllers

package
v0.6.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 2, 2025 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package controllers handles HTTP request routing and API layer logic.

Index

Constants

This section is empty.

Variables

var AllControllers = make(Set)

AllControllers contains all the controllers that are registered by the application

Functions

This section is empty.

Types

type Controller

type Controller interface {
	Init(di *DependencyInjection)
	ServeHTTP(w http.ResponseWriter, r *http.Request)
	BackendType() ControllerBackendType
}

Controller is the interface a controller must satisfy

type ControllerBackendType

type ControllerBackendType byte
const (
	MainController ControllerBackendType = 1 + iota
	AdminController
	AllController
)

type Set

type Set map[string]Controller

Set defines the controllers set for storing all controllers

Directories

Path Synopsis
Package v0 implements version 0 of the public-facing REST API.
Package v0 implements version 0 of the public-facing REST API.

Jump to