Documentation
¶
Overview ¶
Package controllers handles HTTP request routing and API layer logic.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var AllControllers = make(Set)
AllControllers contains all the controllers that are registered by the application
Functions ¶
This section is empty.
Types ¶
type Controller ¶
type Controller interface {
Init(di *DependencyInjection)
ServeHTTP(w http.ResponseWriter, r *http.Request)
BackendType() ControllerBackendType
}
Controller is the interface a controller must satisfy
type ControllerBackendType ¶
type ControllerBackendType byte
const ( MainController ControllerBackendType = 1 + iota AdminController AllController )
type Set ¶
type Set map[string]Controller
Set defines the controllers set for storing all controllers
Click to show internal directories.
Click to hide internal directories.